Changed name "Internetfonden" to "the .SE Internet Fund".
authorNiels Möller <nisse@lysator.liu.se>
Fri, 5 Apr 2013 09:01:38 +0000 (11:01 +0200)
committerNiels Möller <nisse@lysator.liu.se>
Fri, 5 Apr 2013 09:01:38 +0000 (11:01 +0200)
43 files changed:
cnd-copy.c
ecc-192.c
ecc-224.c
ecc-256.c
ecc-384.c
ecc-521.c
ecc-a-to-j.c
ecc-add-jja.c
ecc-add-jjj.c
ecc-curve.h
ecc-dup-jj.c
ecc-ecdsa-sign.c
ecc-ecdsa-verify.c
ecc-generic-modp.c
ecc-generic-modq.c
ecc-generic-redc.c
ecc-hash.c
ecc-internal.h
ecc-j-to-a.c
ecc-mod.c
ecc-modp.c
ecc-modq.c
ecc-mul-a.c
ecc-mul-g.c
ecc-point-mul-g.c
ecc-point-mul.c
ecc-point.c
ecc-random.c
ecc-scalar.c
ecc-size.c
ecc.h
eccdata.c
ecdsa-keygen.c
ecdsa-sign.c
ecdsa-verify.c
ecdsa.h
examples/ecc-benchmark.c
misc/plan.html
nettle.texinfo
sec-add-1.c
sec-modinv.c
sec-sub-1.c
sec-tabselect.c

index 002e44eab332d6bd0c1f0017c7e8b76310502432..8515bfe0eb359dfe5a969a64af0126a84d18117d 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 23015e4a5d30d0c29c024ebe84529d7892a40abf..5026b1eb301bd4a7e4d93eddabda6f8229b1f317 100644 (file)
--- a/ecc-192.c
+++ b/ecc-192.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index cd3d05d617224db49ddba79bb2a35e6c8e42aa1c..825e7e73f9edc3f465bdae21e34195d211aae668 100644 (file)
--- a/ecc-224.c
+++ b/ecc-224.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 8d787c595d0a43b6167f18948ff5049a57635591..571cf73f4e0e8c5edd189da4b57a3fe8b8f57d57 100644 (file)
--- a/ecc-256.c
+++ b/ecc-256.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index ffa19fec229c23db71f319be1bd9f75d4b79d517..8b9a3284fd84be212b1f484d75f37b1ce3348bf5 100644 (file)
--- a/ecc-384.c
+++ b/ecc-384.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index b925878fe35eb7958191aa28ebd8a3052272ecf7..768e366749bd05e16638663faf82eae864426023 100644 (file)
--- a/ecc-521.c
+++ b/ecc-521.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 5fbc0a88dfd12f68f539afb5a777e305a016463b..06bab7e95458e56f391ab38e6f09fbf68d9472d6 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index f358e8ba823f6a5010864c1deb028f3675dfceb0..24ef4ec4824f257ccb3e1fa89e58ffa8a7b8b988 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index e0506375d7b8b323e73850b171c1bc7367d55d4d..22542e8ab8c26e5a7abc62a0ee6a0ecc3fb0e59f 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index e6f8aa6762f5d8b1301997889faf1e475e397445..1dc026b5d5943d265d11fe6e6364920acac4a560 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #ifndef NETTLE_ECC_CURVE_H_INCLUDED
 #define NETTLE_ECC_CURVE_H_INCLUDED
index 3c850d70391262e70ed013b604aaf01eb2ce5185..85d7c3388080de58691018de14b5b087eee0a91e 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index e85c325c9c3b786bee21420565c13d57670fbe53..cdf377465d860f996f94ea49e05b2cb2f4b56113 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 57bbb9b39d837d043e286fca77d99970d54bd5b5..f24eff37185f65ff42b54cfdb5a9cf0d9bca5a2d 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index dd557553b077bb7a06a18277dcf9152c015e1110..8cd9cfad7ef8f03a16d4fccc9f27c33ad1d7752d 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 3fd3879f56e63822a78d47c9c8fec7c7f4d24dae..82978ce78b161ffac745cec0c25c6015ace3e1de 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 1b120b5ebfc95055f70b746033985be3a0e26f53..a6787b7975b273f4cd728c785ecfb034a301afab 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 8040974ff5df5771286f3bb6b1c5d09620a0de65..f63544fb37a0fe5939b98463c8c8f7c35ead2ffd 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 0c3c18b3812107e9f3337834dffb20c1cfd5da50..e8974fe4c9dcfbf794c5db829e686a65e97a2bd0 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #ifndef NETTLE_ECC_INTERNAL_H_INCLUDED
 #define NETTLE_ECC_INTERNAL_H_INCLUDED
index ae56bbaf6df33bcb484b74d68580a942e45199e1..df8b876490e797342176583839fdf753c2cadf41 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 1d2f4232b6ab35cbe35d0e1cd774736b8b2852e1..ef807ff9f847ecc0a06b38840563a158372d2b22 100644 (file)
--- a/ecc-mod.c
+++ b/ecc-mod.c
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index ce7de7c8242b922b8935e5b4bf08073b926ac108..91b44e3d3ac3615b6bfa0dd3c495464dcd810fe9 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 80a719a55a29962ecbf72a86c2bef53472a6f9ef..af5e31f849f24a6ca9c932f6c0306d5292caeec5 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 0b347162d6dbccf46923f29ec8ae6152ce78013e..b23bdc5d904a59d218f937c06974418d6f285837 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index e202e26b3e35f4e65eb7ee6f9a669598b17a2009..d95e518d76c13654a5d72112ae048afafbe4e154 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index e6f51f180ef09454ec3cb396859f53270fc52d0c..78824d2813667e27bdfbf5e0ba7d5c8e0ce74200 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 2ecea1f9ac2b523883fa423fcb8525f161216028..dd292cb0303c79301c553260088321cc1b0e791a 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 82645a79df350b035fd154e506fbde8bf44c8478..3f356b957890b2bae5fbd3d76568c6029affa079 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 0866a7d42ffe82517addf8a05b824fafb6544e23..dda291024c5b293c0c695e615e27f6bc94416926 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 2b3c4176edd918139f0d8f2750216fd6c5cb89ca..27d657193ea4929ba572064af8705ead76eebda6 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index c829d46050bccb872385690bbf4cf4eac6e6493c..c54bfbb8e2433138c116a043c0e937dbfd706b10 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
diff --git a/ecc.h b/ecc.h
index b78e86d8cac6da11a9e8ab050687ce9a982e5aeb..609d2468cf11f4c2e03ab2bb52168ab3e244199e 100644 (file)
--- a/ecc.h
+++ b/ecc.h
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #ifndef NETTLE_ECC_H_INCLUDED
 #define NETTLE_ECC_H_INCLUDED
index ea922b5d74c5be5dd371c271238c66593f7bee67..9cc24f1ac42e25a979950d8a300b28a667e1ae43 100644 (file)
--- a/eccdata.c
+++ b/eccdata.c
@@ -22,7 +22,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #include <assert.h>
 #include <stdio.h>
index 7f8a37f1eaafee1ab992259ed5eaa9a41808fa63..e83d282b8d04995ddb8cca5a340c4c4837204b6b 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index fadd342460e60c90ea4c67a1605d0b67251baf25..2ee019c8c9714bcc56979f5fd144054a012096f8 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 7696d59d2eaee7a156124ada121360d74c5ad5e2..d889d780b79fa0b03e6b7487c190827c5d996eda 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
diff --git a/ecdsa.h b/ecdsa.h
index 961102e58a4e1cb405839057b594d38507b48d5f..17267a92686dff85b446b6967038c24cfe4e204c 100644 (file)
--- a/ecdsa.h
+++ b/ecdsa.h
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #ifndef NETTLE_ECDSA_H_INCLUDED
 #define NETTLE_ECDSA_H_INCLUDED
index e14e55ef1a3d662969c6f51048b7052b1b0ed9c9..1faf6dc5c62e1af7fe790bdf9e7934930ac509d4 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 4e01a053072fbeb3aa74c7e2f850c29900da4d77..561226b2c7f2a7eb1edcb50bac5d2a58bbe4ee3b 100644 (file)
@@ -37,6 +37,9 @@
     Make use of GMP's mpn_cnd_add_n and mpn_sub_n (which will be
     available in the next GMP release).
   </p>
+  <p class='should'>
+    Implement <tt>ecc_point_mul</tt> and <tt>ecc_point_mul_g</tt>.
+  </p>  
   <p class='should'>
     Rewrite x86_64/sha3-permute.asm. Moves between xmm registers and
     regular registers kill performance at least on some AMD
index 75469c23125fa48a0eb9bc2b02d9976b8f6eed74..a5429a5fc279ea3ecd76e5b903dc7128be11fb97 100644 (file)
@@ -250,7 +250,7 @@ for bignum operations.
 @item ECDSA
 Written by @value{AUTHOR}, released under the LGPL. Uses the GMP library
 for bignum operations. Development of Nettle's ECC support was funded by
-Internetfonden.
+the .SE Internet Fund.
 @end table
 
 @node Conventions, Example, Copyright, Top
@@ -3749,7 +3749,7 @@ End:
 @c  LocalWords:  XORs cryptologists libnettle libhogweed GCM ECDSA NTT
 @c  LocalWords:  toolkits BLOWFISH Möller RIPEMD libgcrypt PBKDF Shishi
 @c  LocalWords:  GnuTLS Gutmann's GOSTHASH GOST Aleksey Kravchenko ECC
-@c  LocalWords:  rhash Mavrogiannopoulos Internetfonden Keccak Bertoni
+@c  LocalWords:  rhash Mavrogiannopoulos Keccak Bertoni
 @c  LocalWords:  Michaël Peeters Assche Dobbertin Antoon Bosselaers KDF
 @c  LocalWords:  Preneel rôle McGrew Viega KDFs PBKDFs passphrase PRF
 @c  LocalWords:  th deallocate pre bitsize multi lookup secp startup
index 7e7b44338ea72c7f1e3eda6930e6a3fca6615a64..1e3720e868e7343168e18be1eb40c7c3401754d3 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index f674a8fb8d285ea94b4302e3e53623d0df6e3fff..0991a98c9155458da18ba21d5861b9eaa9729ad0 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index 1aa04d04731e982254a021cde35f11658213d36c..f2fec316b0171da2b04260f687553422933805de 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
index f9e3c8c524de7acd0ee116b3b1fff2e84b1e466b..026680e32403a356fb33ec5f9eed1e8a47026f86 100644 (file)
@@ -20,7 +20,7 @@
  * MA 02111-1301, USA.
  */
 
/* Development of Nettle's ECC support was funded by Internetfonden. */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #ifndef NETTLE_ECDSA_H_INCLUDED
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H
@@ -20,7 +20,7 @@
  */
 
-/* Development of Nettle's ECC support was funded by Internetfonden. */
+/* Development of Nettle's ECC support was funded by the .SE Internet Fund. */
 
 #if HAVE_CONFIG_H